@@ -27,8 +27,8 @@ def exists_base_object(table_name, schem_aname='public'):
             return len(rows) > 0
 
 
-def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None) -> Text:
-    if exists_base_object(mat_view_name):
+def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None, check_exists=False) -> Text:
+    if check_exists == True and check_exists is not None and exists_base_object(mat_view_name):
         return mat_view_name
 
     key = f'create_tmp_mat_view_{mat_view_name}'
