@@ -1,33 +1,22 @@
 import json
 
 from bitfield import BitHandler
-from django.core.serializers.json import DjangoJSONEncoder
 from django.db.models.fields.files import FieldFile
 from django.http import HttpResponse
 
 from isc_common import setAttr
+from isc_common.http.JSONEncoder import JSONEncoder
 
 
 class JsonResponse(HttpResponse):
-    """
-    An HTTP response class that consumes data to be serialized to JSON.
 
-    :param data: Data to be dumped into json. By default only ``dict`` objects
-      are allowed to be passed due to a security flaw before EcmaScript 5. See
-    :param encoder: Should be a json encoder class. Defaults to
-      ``django.core.serializers.json.DjangoJSONEncoder``.
-    :param safe: Controls if only ``dict`` objects may be serialized. Defaults
-      to ``True``.
-    :param json_dumps_params: A dictionary of kwargs passed to json.dumps().
-    """
-
-    def __init__(self, data, encoder=DjangoJSONEncoder, safe=True, json_dumps_params=None, **kwargs):
+    def __init__(self, data, encoder=JSONEncoder, safe=True, json_dumps_params=None, **kwargs):
         if safe and not isinstance(data, dict):
             raise TypeError(
                 'In order to allow non-dict objects to be serialized set the '
                 'safe parameter to False.'
             )
-        if json_dumps_params is None:
+        if json_dumps_params == None:
             json_dumps_params = dict()
         kwargs.setdefault('content_type', 'application/json')
         self.container_data = data
@@ -37,13 +26,13 @@ class JsonResponse(HttpResponse):
 
 class JsonResponseLookup(HttpResponse):
 
-    def __init__(self, data, encoder=DjangoJSONEncoder, safe=True, json_dumps_params=None, **kwargs):
+    def __init__(self, data, encoder=JSONEncoder, safe=True, json_dumps_params=None, **kwargs):
         if safe and not isinstance(data, dict):
             raise TypeError(
                 'In order to allow non-dict objects to be serialized set the '
                 'safe parameter to False.'
             )
-        if json_dumps_params is None:
+        if json_dumps_params == None:
             json_dumps_params = dict()
 
         kwargs.setdefault('content_type', 'application/json')
