@@ -13,9 +13,10 @@ def del_last_zero(value):
         return value
 
     res = str(value)
-    res.split('.')
+    # res.split('.')
     cel = res.split('.')[0]
-    float = StrToNumber(res.split('.')[1:][0])
+    float = res.split('.')[1:4][0].rstrip('0')
+    float = StrToNumber(float)
     if float > 0:
         return f'{cel}.{float}'
     return cel
@@ -29,7 +30,8 @@ def DecimalToStr(value):
         # if value == 0:
         #     return None
 
-        return del_last_zero(value=value)
+        res = del_last_zero(value=value)
+        return res
     except IndexError:
         return value
 
@@ -38,6 +40,9 @@ def StrToNumber(s1):
     if s1 == None:
         return None
 
+    if s1 == '':
+        return 0
+
     if not isinstance(s1, str):
         raise Exception(f'{s1} is not str type.')
 
