@@ -164,6 +164,11 @@ class WebSocket:
         setAttr(kwrags, 'type', 'info')
         WebSocket.send_typing_message(**kwrags)
 
+    @staticmethod
+    def send_ask_message(**kwrags):
+        setAttr(kwrags, 'type', 'ask')
+        WebSocket.send_typing_message(**kwrags)
+
     @staticmethod
     def send_typing_message(**kwrags):
 
@@ -172,9 +177,12 @@ class WebSocket:
             raise Exception(f'channel is not type.')
 
         message = kwrags.get('message')
+        callbackData = kwrags.get('callbackData')
+
         if isinstance(message, str):
             message = dict(
                 message=message,
+                callbackData=callbackData,
                 type=type,
             )
 
